#!/usr/bin/env python

__author__ = "Christopher Hahne"
__email__ = "inbox@christopherhahne.de"
__license__ = """
Copyright (c) 2019 Christopher Hahne <inbox@christopherhahne.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

"""

from numpy import dot, transpose
from numpy.linalg import inv

def solve_sle(A, b):
    ''' function solver for system of linear equations '''

    if is_square(A):
        A_inv = inv(A)
    else:
        A_inv = pseudo_inv(A)

    return dot(A_inv, b)

def is_square(A):
    ''' check if matrix is square'''

    return all(len(row) == len(A) for row in A)

def pseudo_inv(A):
    ''' compute pseudo inverse '''

    return dot(transpose(A), inv(dot(A, transpose(A))))